@@ -1,5 +1,5 @@
 from ..common import require
-from . import aplus
+from . import aplus, acosjson, mongodump
 
 TYPES = [
   {
@@ -7,20 +7,32 @@ TYPES = [
     'name': 'A-plus-LMS, https://apluslms.github.io/',
     'add': aplus.interactive_connect,
     'construct': aplus.construct_client,
-  }
+  },
+  {
+    'id': 'acosjson',
+    'name': 'JSON log files from https://github.com/acos-server/acos-server',
+    'add': acosjson.interactive_connect,
+    'construct': acosjson.construct_client,
+  },
+  {
+    'id': 'mongodump',
+    'name': 'Database export from https://docs.mongodb.com/database-tools/mongodump/',
+    'add': mongodump.interactive_connect,
+    'construct': mongodump.construct_client,
+  },
 ]
 
 def interactive_add(type):
   return type['add']()
 
-def select_type(id):
+def select_type(type):
   for t in TYPES:
-    if t['id'] == id:
+    if t['id'] == type:
       return t
   return None
 
 def create_client(src):
-  t = select_type(src["id"])
+  t = select_type(src['type'])
   if t:
     return t['construct'](src)
   return None
@@ -36,7 +48,8 @@ def get_sources_with_tables(config):
     sources.append({
       'id': i,
       'name': src['name'],
-      'api': api,
+      'type': src['type'],
       'tables': tables,
+      'api': api,
     })
   return sources
